@@ -54,6 +54,8 @@ class Runner:
         self.job = job_run["job"]
         self.job_run = job_run
         self.job_settings = job_run["jobSettings"]
+        self.hardware = self.primitive.hardware.get_own_hardware_details()
+        self.hardware_secret = None
         self.target_hardware_id = target_hardware_id
         self.target_hardware: dict | None = None
         self.target_hardware_secret = None
@@ -84,6 +86,13 @@ class Runner:
                 k: v for k, v in target_hardware_secret.items() if v is not None
             }
 
+            hardware_secret = self.primitive.hardware.get_hardware_secret(
+                hardware_id=self.hardware["id"]
+            )
+            self.hardware_secret = {
+                k: v for k, v in hardware_secret.items() if v is not None
+            }
+
     @log_context(label="setup")
     def setup(self) -> None:
         # Attempt to download the job source code
@@ -285,6 +294,7 @@ class Runner:
                         is_online=False,
                         is_rebooting=True,
                         start_rebooting_at=str(datetime.now(timezone.utc)),
+                        requires_operating_system_installation=False,
                     )
                     logger.info(
                         "Box rebooting, waiting 30 seconds before beginning SSH connection."
@@ -311,20 +321,36 @@ class Runner:
             ):
                 logger.info("Setting next boot to PXE and rebooting")
 
+                organization_id = self.target_hardware.get("organization", {}).get("id")
+                operating_system_slug = self.target_hardware.get(
+                    "defaultOperatingSystem", {}
+                ).get("slug")
+
+                iso_filename = self.target_hardware.get("defaultOperatingSystem")[
+                    "isoFile"
+                ].get("fileName")
+
+                # TODO dynamically obtain this later
+                file_server_hostname = "192.168.10.1"
+
+                target_ip_address = self.target_hardware_secret.get("hostname", "")
+                target_username = self.target_hardware_secret.get("username", "")
+                target_password = self.target_hardware_secret.get("password", "")
+                target_machine_name = self.target_hardware.get("slug", "")
+                target_auth_token = self.primitive.host_config.get("token", "")
+
                 await sync_to_async(
                     self.primitive.operating_systems._prepare_operating_system_for_pxe
                 )(
-                    organization_id=self.target_hardware.get("organization", {}).get(
-                        "id"
-                    ),
-                    operating_system_slug=self.target_hardware.get(
-                        "defaultOperatingSystem", {}
-                    ).get("slug"),
-                    iso_filename=self.target_hardware.get("defaultOperatingSystem")
-                    .get("isoFile")
-                    .get("fileName"),
-                    controller_hostname="192.168.10.1",  # TODO dynamically obtain this later
-                    target_ip_address=self.target_hardware_secret.get("hostname", ""),
+                    organization_id=organization_id,
+                    operating_system_slug=operating_system_slug,
+                    iso_filename=iso_filename,
+                    file_server_hostname=file_server_hostname,
+                    target_ip_address=target_ip_address,
+                    target_username=target_username,
+                    target_password=target_password,
+                    target_machine_name=target_machine_name,
+                    target_auth_token=target_auth_token,
                 )
                 pxe_boot(target_hardware_secret=self.target_hardware_secret)
 
