@@ -11,10 +11,11 @@ HOME_DIRECTORY = Path.home()
 
 
 class LaunchService(Daemon):
-    def __init__(self, label: str, command: str):
+    def __init__(self, label: str, command: str, root_user: bool = False) -> None:
         self.label = label
         self.name = label.split(".")[-1]
         self.command = command
+        self.root_user = root_user
 
     @property
     def service_name(self) -> str:
@@ -22,16 +23,25 @@ class LaunchService(Daemon):
 
     @property
     def file_path(self) -> Path:
-        return Path(HOME_DIRECTORY / ".config" / "systemd" / "user" / self.service_name)
+        if self.root_user:
+            return Path("/etc/systemd/system") / self.service_name
+        else:
+            return HOME_DIRECTORY / ".config" / "systemd" / "user" / self.service_name
 
     @property
     def logs(self) -> Path:
-        return Path(HOME_DIRECTORY / ".cache" / "primitive" / f"{self.label}.log")
+        if self.root_user:
+            return Path("/var/log") / f"{self.label}.log"
+        else:
+            return Path(HOME_DIRECTORY / ".cache" / "primitive" / f"{self.label}.log")
 
     def stop(self) -> bool:
         try:
             if self.is_active():
-                stop_existing_service = f"systemctl --user stop {self.service_name}"
+                if self.root_user:
+                    stop_existing_service = f"sudo systemctl stop {self.service_name}"
+                else:
+                    stop_existing_service = f"systemctl --user stop {self.service_name}"
                 subprocess.check_output(
                     stop_existing_service.split(" "), stderr=subprocess.DEVNULL
                 )
@@ -48,7 +58,10 @@ class LaunchService(Daemon):
 
     def start(self) -> bool:
         try:
-            start_new_service = f"systemctl --user start {self.service_name}"
+            if self.root_user:
+                start_new_service = f"sudo systemctl start {self.service_name}"
+            else:
+                start_new_service = f"systemctl --user start {self.service_name}"
             subprocess.check_output(start_new_service.split(" "))
             logger.info(f":white_check_mark: {self.label} started successfully!")
             return True
@@ -60,9 +73,14 @@ class LaunchService(Daemon):
     def disable(self) -> bool:
         try:
             if self.is_installed():
-                disable_existing_service = (
-                    f"systemctl --user disable {self.service_name}"
-                )
+                if self.root_user:
+                    disable_existing_service = (
+                        f"sudo systemctl disable {self.service_name}"
+                    )
+                else:
+                    disable_existing_service = (
+                        f"systemctl --user disable {self.service_name}"
+                    )
                 subprocess.check_output(
                     disable_existing_service.split(" "), stderr=subprocess.DEVNULL
                 )
@@ -74,7 +92,10 @@ class LaunchService(Daemon):
 
     def enable(self) -> bool:
         try:
-            enable_service = f"systemctl --user enable {self.service_name}"
+            if self.root_user:
+                enable_service = f"sudo systemctl enable {self.service_name}"
+            else:
+                enable_service = f"systemctl --user enable {self.service_name}"
             subprocess.check_output(
                 enable_service.split(" "), stderr=subprocess.DEVNULL
             )
@@ -85,9 +106,14 @@ class LaunchService(Daemon):
             return False
 
     def verify(self) -> bool:
-        systemctl_check = (
-            f"systemctl --user show {self.service_name} -p CanStart --value"
-        )
+        if self.root_user:
+            systemctl_check = (
+                f"sudo systemctl show {self.service_name} -p CanStart --value"
+            )
+        else:
+            systemctl_check = (
+                f"systemctl --user show {self.service_name} -p CanStart --value"
+            )
         try:
             output = (
                 subprocess.check_output(systemctl_check.split(" ")).decode().strip()
@@ -137,7 +163,7 @@ class LaunchService(Daemon):
         }
 
         config["Install"] = {
-            "WantedBy": "default.target",
+            "WantedBy": "multi-user.target",
         }
 
         try:
@@ -213,9 +239,14 @@ class LaunchService(Daemon):
 
     def is_active(self) -> bool:
         try:
-            is_service_active = (
-                f"systemctl --user show {self.service_name} -p ActiveState --value"
-            )
+            if self.root_user:
+                is_service_active = (
+                    f"sudo systemctl show {self.service_name} -p ActiveState --value"
+                )
+            else:
+                is_service_active = (
+                    f"systemctl --user show {self.service_name} -p ActiveState --value"
+                )
             output = (
                 subprocess.check_output(is_service_active.split(" ")).decode().strip()
             )
@@ -227,9 +258,12 @@ class LaunchService(Daemon):
 
     def is_installed(self) -> bool:
         try:
-            is_service_active = (
-                f"systemctl --user show {self.service_name} -p UnitFileState --value"  # noqa
-            )
+            if self.root_user:
+                is_service_active = (
+                    f"sudo systemctl show {self.service_name} -p UnitFileState --value"  # noqa
+                )
+            else:
+                is_service_active = f"systemctl --user show {self.service_name} -p UnitFileState --value"  # noqa
             output = (
                 subprocess.check_output(is_service_active.split(" ")).decode().strip()
             )
