@@ -1,4 +1,21 @@
 from primitive.graphql.utility_fragments import operation_info_fragment
+from primitive.hardware.graphql.fragments import hardware_fragment
+
+hardware_certificate_create_mutation = (
+    operation_info_fragment
+    + """
+mutation hardwareCertificateCreate($input: HardwareCertificateCreateInput!) {
+    hardwareCertificateCreate(input: $input) {
+        __typename
+        ... on HardwareCertificate {
+            id
+            certificatePem
+        }
+        ...OperationInfoFragment
+    }
+}
+"""
+)
 
 register_hardware_mutation = (
     operation_info_fragment
@@ -6,6 +23,8 @@ register_hardware_mutation = (
 mutation registerHardware($input: RegisterHardwareInput!) {
     registerHardware(input: $input) {
         ... on Hardware {
+            id
+            pk
             fingerprint
         }
         ...OperationInfoFragment
@@ -42,8 +61,7 @@ mutation unregisterHardware($input: UnregisterHardwareInput!) {
 """
 )
 
-
-hardware_update_mutation = (
+hardware_update_system_info_mutation = (
     operation_info_fragment
     + """
 mutation hardwareUpdate($input: HardwareUpdateInput!) {
@@ -57,6 +75,21 @@ mutation hardwareUpdate($input: HardwareUpdateInput!) {
 """
 )
 
+hardware_update_mutation = (
+    operation_info_fragment
+    + hardware_fragment
+    + """
+mutation hardwareUpdate($input: HardwareUpdateInput!) {
+    hardwareUpdate(input: $input) {
+        ... on Hardware {
+            ...HardwareFragment
+        }
+        ...OperationInfoFragment
+    }
+}
+"""
+)
+
 hardware_checkin_mutation = (
     operation_info_fragment
     + """
