@@ -958,21 +958,20 @@ autoinstall:
             user_data_script_file.unlink()
         with open(user_data_script_file, "w") as user_data_script:
             user_data_script.write(f"""#! /bin/bash
-# LOGS ARE LOCATED AT var/log/cloud-init-output.log
+# LOGS ARE LOCATED AT /var/log/cloud-init-output.log
+ls -la
+pwd
 echo $USER
-echo $ENV
-
 curl -LsSf https://astral.sh/uv/install.sh | sh
-source $HOME/.local/bin/env
-source $HOME/.bashrc
+. /$USER/.local/bin/env
+. /$USER/.bashrc
 uv python install --default 3.14.0
-uv venv
-uv init
-source $HOME/.venv/bin/activate
-uv add --no-cache primitive
-primitive --host api.dev.primitive.tech config --auth-token {target_auth_token}
-primitive --host api.dev.primitive.tech hardware register --issue-certificate
-primitive --debug --host api.dev.primitive.tech daemons install
+uv venv --no-project
+. /$USER/.venv/bin/activate
+uv pip install --no-cache primitive
+primitive --host {self.primitive.host} config --auth-token {target_auth_token}
+primitive --host {self.primitive.host} hardware register --issue-certificate
+primitive --debug --host {self.primitive.host} daemons install
 """)
 
     def _prepare_operating_system_for_pxe(
