@@ -1,6 +1,6 @@
-import typing
+from typing import TYPE_CHECKING
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
     import primitive.client
 
 
